from django.conf import settings
from django.contrib.staticfiles.storage import staticfiles_storage
from django.core.files.base import ContentFile
from django.core.management.base import BaseCommand

from ...core import generate_js


class Command(BaseCommand):
    help = "Creates a static choices.js file for django-js-choices"

    def add_arguments(self, parser):
        parser.add_argument(
            "-l",
            "--locale",
            action="store",
            dest="locale",
            default=settings.LANGUAGE_CODE,
            help="Locale to generate choices file",
        )

    def handle(self, *args, **options):
        locale = options["locale"]
        content = generate_js(locale)
        file_name = staticfiles_storage.path(f"choices-{locale}.js")
        if staticfiles_storage.exists(file_name):
            staticfiles_storage.delete(file_name)
        staticfiles_storage.save(file_name, ContentFile(content))
        self.stdout.write(f"{file_name} saved to static root!")



from django.http import HttpResponse

from .core import generate_js


def choices_js(request):
    locale = request.GET.get("lang", None) or request.GET.get("locale", None)
    js_content = generate_js(locale)
    return HttpResponse(js_content, content_type="application/javascript")



from django import template
from django.utils.safestring import mark_safe

from ..core import generate_js

register = template.Library()


@register.simple_tag(takes_context=True)
def js_choices_inline(context):
    """
    Outputs a string of javascript that can access model field choices.
    """
    locale = None
    if "request" in context:
        request = context["request"]
        locale = locale = request.GET.get("lang", None) or request.GET.get("locale", None)
    return mark_safe(generate_js(locale))
